/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _U2_PSIPRED_PLUGIN_H_
#define _U2_PSIPRED_PLUGIN_H_

#include <U2Core/PluginModel.h>
#include <U2Gui/ObjectViewModel.h>
#include <U2Core/AnnotationData.h>


namespace U2 {

class XMLTestFactory;

class PsipredPlugin : public Plugin {
	Q_OBJECT
public:
    PsipredPlugin();
	~PsipredPlugin();

private:
    GObjectViewWindowContext* viewCtx;
};


} //namespace

#endif // _U2_PSIPRED_PLUGIN_H_


